<script setup>
import { Head, Link, useForm } from '@inertiajs/inertia-vue3';
import Welcome from '@/Jetstream/Welcome.vue';
import JetButton from '@/Jetstream/Button.vue';
import JetModal from '@/Jetstream/Modal.vue';
import DK_Button from '@/components/dk_Button.vue';
import DK_Input from '@/components/dk_Input.vue';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style scoped>

.dataTables_filter{
    visibility: visible;
}

table {
    border-color: transparent !important;
}

table.dataTable thead .sorting {
    background-image: none !important;
}

table.dataTable thead .sorting_asc,
table.dataTable thead .sorting_desc {
    background-image: none !important;
    color: white !important;
    font-weight: 600 !important;
}

.dataTables_wrapper {
    margin-bottom: 0.5rem !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
    cursor: default;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 1px solid transparent;
    background: transparent;
    box-shadow: none;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
    box-sizing: border-box;
    display: inline-block;
    min-width: 1.5em;
    padding: 0.5em 1em;
    margin-left: 2px;
    text-align: center;
    text-decoration: none !important;
    cursor: pointer;
    cursor: hand;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 0;
    border-radius: 0.375rem;
}

.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: rgba(200, 200, 200, 1) !important;
    background-color: rgba(0, 152, 219, 0.1) !important;
    background-image: unset !important;
    border: 0;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.current,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover {
    color: rgba(255, 250, 250, 1) !important;
    border: 0 !important;
    background-color: rgba(0, 152, 219, 0.2) !important;
    background-image: unset !important;
    border-bottom-width: 2px;
    border-bottom-color: rgba(255, 250, 250, 1);
    border-radius: 0.375rem;
}

.dataTable thead th,
.dataTable thead td {
    padding-top: 0 !important;
    padding-bottom: 0 !important;
}

table.dataTable thead th,
table.dataTable thead td {
    padding: 0px 10px;
    font-size: 0.9rem !important;
    border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
}

select:hover {
    background-color: transparent;
}

::-webkit-scrollbar {
    height: 2px;
}

</style>

<template>
    <AppLayout title="ManageProfiles">
        <loader-component></loader-component>
        <div v-if="this.screen_width >= 768" style="height: calc(100vh - 4.75rem);"
            class="bg-darkblue-background px-6 py-4 z-0 cursor-default select-none">
            <div class="grid justify-items-stretch pb-4">
                <div class="justify-between self-center items-center flex w-full">
                    <p class="text-white-snow font-light text-center text-2xl">{{ this.$t("general." + "Manage profiles") }} </p>

                    <div class="flex gap-2 items-end">

                        <div class="mt-auto">
                            <DK_Button color="blue" :fixedSize="false" width="fit" v-on:click="this.openCreateUser()">
                                {{ this.$t("general.Create new user") }}
                            </DK_Button>
                        </div>

                        <DK_Button class="" color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                            {{ this.$t("general.Back") }}
                        </DK_Button>

                    </div>
                </div>
            </div>
            <div class="py-4 px-6 baltoro-container">
                <table id="basicTable" class="row-border">
                    <thead class="bg-transparent text-gray-light my-2">
                        <tr>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "User") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "Name") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "Email") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "Register Date") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "Update Date") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "User Level") }}</th>
                            <th class="whitepace-nowrap">{{ this.$t("general." + "Edit") }}</th>
                        </tr>
                    </thead>
                    <tbody class="text-center">
                        <tr v-for="user_temp in users_list" :key="user_temp.id" class="h-10">
                            <td>{{ user_temp.user }}</td>
                            <td>{{ user_temp.name }}</td>
                            <td>{{ user_temp.email }}</td>
                            <td>{{ this.formatter(user_temp.created_at, this.user) }}</td>
                            <td>{{ this.formatter(user_temp.updated_at, this.user) }}</td>
                            <td class="w-20">
                                <div class="text-white-snow rounded text-xs pt-0.5 pb-1"
                                    v-bind:class='{ "bg-lvl-datakorum": user_temp.admin == 0, "bg-lvl-admin": user_temp.admin == 1, "bg-lvl-analyst": user_temp.admin == 2, "bg-lvl-user": user_temp.admin == 3 }'>
                                    {{ admin_level[user_temp.admin] }}
                                </div>
                            </td>
                            <!-- v-bind:class='{"bg-green-500 ": user.admin==1, "bg-red-500 ": user.admin==2, "bg-yellow-500 ": user.admin==3, "bg-cyan-text ": true}' -->
                            <td>
                                <div v-if="user_temp.admin >= this.user.admin"
                                    class="flex items-center justify-center">
                                    <svg width="20px" height="20px" viewBox="0 0 24 24" version="1.1" class="cursor-pointer"
                                        v-on:click="this.openEditUser(user_temp.id)">
                                        <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
                                            <rect x="0" y="0" width="24" height="24" />
                                            <path
                                                d="M8, 17.9148182 L8, 5.96685884 C8, 5.56391781 8.16211443, 5.17792052 8.44982609, 4.89581508 L10.965708, 2.42895648 C11.5426798, 1.86322723 12.4640974, 1.85620921 13.0496196, 2.41308426 L15.5337377, 4.77566479 C15.8314604, 5.0588212 16, 5.45170806 16, 5.86258077 L16, 17.9148182 C16, 18.7432453 15.3284271, 19.4148182 14.5, 19.4148182 L9.5, 19.4148182 C8.67157288, 19.4148182 8, 18.7432453 8, 17.9148182 Z"
                                                fill="#FFFAFA" opacity="0.85" fill-rule="nonzero"
                                                transform="translate(12.000000, 10.707409) rotate(-135.000000) translate(-12.000000, -10.707409) " />
                                            <rect fill="#FFFAFA" opacity="0.85" x="5" y="20" width="15" height="2" rx="1" />
                                        </g>
                                    </svg>
                                </div>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <div v-else style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background p-4 z-0 cursor-default flex flex-col gap-4 overflow-hidden">
            <div class="w-full flex flex-col justify-center items-start pt-2 pb-1 gap-2">
                <div class="w-full flex flex-row justify-between px-3">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.$t("general." + "Manage profiles") }} </p>
                        </div>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="flex items-center justify-center">

                            <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center" v-on:click="this.openCreateUser()">
                                <svg width="14px" height="14px" viewBox="0 0 24 24" version="1.1">
                                    <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
                                        <rect fill="#FFFAFA" x="4" y="11" width="16" height="2" rx="1"/>
                                        <rect fill="#FFFAFA" transform="translate(12.000000, 12.000000) rotate(-270.000000) translate(-12.000000, -12.000000) " x="4" y="11" width="16" height="2" rx="1"/>
                                    </g>
                                </svg>
                            </button>

                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>

                <div class="pt-2 px-4 baltoro-container h-50px w-full">
                    <table id="basicTable" class="row-border">
                        <thead class="bg-transparent">
                            <tr>
                                <th></th>
                                <th></th>
                            </tr>
                        </thead>
                        <tbody class="text-center">
                            <tr v-for="(user_temp, index) in users_list" :key="user_temp.id" class="h-10" v-on:click="this.OpenRow(index)">
                                <td>
                                    <i class="fa-solid transition duration-100 fa-angle-down " v-bind:class="{'-rotate-90 ' : this.GW_open[index], }" style="font-size:0.9rem; color:rgba(240,240,240,0.8);"></i>
                                </td>

                                <td class="grid grid-cols-2 gap-y-1 h-8 place-items-stretch" v-if="!this.GW_open[index]" >

                                    <!-- <div class="grid grid-cols-2 place-items-start gap-y-1"> -->
                                        <div class="h-full flex items-center justify-start" ><p class="text-base text-left">{{ user_temp.user }}</p></div>
                                        <!-- <div class="text-base">{{ user_temp.name }}</div> -->

                                        <div class="flex flex-row justify-end items-center">
                                            <div class="w-fit ">
                                                <div class="flex items-center justify-center px-1 py-0.5 w-full text-white-snow rounded text-xs pt-0.5 pb-1"
                                                    v-bind:class='{ "bg-lvl-datakorum": user_temp.admin == 0, "bg-lvl-admin": user_temp.admin == 1, "bg-lvl-analyst": user_temp.admin == 2, "bg-lvl-user": user_temp.admin == 3 }'>
                                                    {{ admin_level[user_temp.admin] }}
                                                </div>
                                            </div>
                                            <div class="w-fit ">
                                                <div v-if="user_temp.admin >= this.user.admin"
                                                    class=" flex items-center justify-center px-1 py-0.5 w-full justify-center">
                                                    <svg width="20px" height="20px" viewBox="0 0 24 24" version="1.1" class="cursor-pointer"
                                                        v-on:click.stop="this.openEditUser(user_temp.id)">
                                                        <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
                                                            <rect x="0" y="0" width="24" height="24" />
                                                            <path
                                                                d="M8, 17.9148182 L8, 5.96685884 C8, 5.56391781 8.16211443, 5.17792052 8.44982609, 4.89581508 L10.965708, 2.42895648 C11.5426798, 1.86322723 12.4640974, 1.85620921 13.0496196, 2.41308426 L15.5337377, 4.77566479 C15.8314604, 5.0588212 16, 5.45170806 16, 5.86258077 L16, 17.9148182 C16, 18.7432453 15.3284271, 19.4148182 14.5, 19.4148182 L9.5, 19.4148182 C8.67157288, 19.4148182 8, 18.7432453 8, 17.9148182 Z"
                                                                fill="#FFFAFA" opacity="0.85" fill-rule="nonzero"
                                                                transform="translate(12.000000, 10.707409) rotate(-135.000000) translate(-12.000000, -10.707409) " />
                                                            <rect fill="#FFFAFA" opacity="0.85" x="5" y="20" width="15" height="2" rx="1" />
                                                        </g>
                                                    </svg>
                                                </div>
                                            </div>
                                        </div>
                                    <!-- </div>     -->

                                </td>
                                <td v-else>
                                    <div class="grid grid-cols-2 gap-y-1 py-1">
                                        <div class="text-gray-light text-base text-left">{{ user_temp.user }}</div>

                                        <div class="flex flex-row justify-end items-center">
                                            <div class="w-fit ">
                                                <div class="flex items-center justify-center px-1 py-0.5 w-full text-white-snow rounded text-xs pt-0.5 pb-1"
                                                    v-bind:class='{ "bg-lvl-datakorum": user_temp.admin == 0, "bg-lvl-admin": user_temp.admin == 1, "bg-lvl-analyst": user_temp.admin == 2, "bg-lvl-user": user_temp.admin == 3 }'>
                                                    {{ admin_level[user_temp.admin] }}
                                                </div>
                                            </div>
                                            <div class="w-fit">
                                                <div v-if="user_temp.admin >= this.user.admin"
                                                    class="flex items-center justify-center px-1 py-0.5 w-full flex items-center justify-center">
                                                    <svg width="20px" height="20px" viewBox="0 0 24 24" version="1.1" class="cursor-pointer"
                                                        v-on:click="this.openEditUser(user_temp.id)">
                                                        <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
                                                            <rect x="0" y="0" width="24" height="24" />
                                                            <path
                                                                d="M8, 17.9148182 L8, 5.96685884 C8, 5.56391781 8.16211443, 5.17792052 8.44982609, 4.89581508 L10.965708, 2.42895648 C11.5426798, 1.86322723 12.4640974, 1.85620921 13.0496196, 2.41308426 L15.5337377, 4.77566479 C15.8314604, 5.0588212 16, 5.45170806 16, 5.86258077 L16, 17.9148182 C16, 18.7432453 15.3284271, 19.4148182 14.5, 19.4148182 L9.5, 19.4148182 C8.67157288, 19.4148182 8, 18.7432453 8, 17.9148182 Z"
                                                                fill="#FFFAFA" opacity="0.85" fill-rule="nonzero"
                                                                transform="translate(12.000000, 10.707409) rotate(-135.000000) translate(-12.000000, -10.707409) " />
                                                            <rect fill="#FFFAFA" opacity="0.85" x="5" y="20" width="15" height="2" rx="1" />
                                                        </g>
                                                    </svg>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="text-cyan-text text-xs text-left">{{ this.$t("general.Name") }}</div>
                                        <div class="text-left"  style="font-size: 0.68rem;">{{user_temp.name}}</div>

                                        <div class="text-cyan-text text-xs text-left">{{ this.$t("general.Email") }}</div>
                                        <div class="text-left " style="font-size: 0.68rem;">{{ user_temp.email}}</div>

                                        <div class="text-cyan-text text-xs text-left">{{ this.$t("general.Register") }}</div>
                                        <div class="text-left" style="font-size: 0.68rem;">{{ this.formatter(user_temp.created_at, this.user)}}</div>

                                        <div class="text-cyan-text text-xs text-left">{{ this.$t("general.Update date simplified") }}</div>
                                        <div class="text-left" style="font-size: 0.68rem;">{{ this.formatter(user_temp.updated_at, this.user) }}</div>

                                    </div>

                                </td>

                            </tr>

                        </tbody>
                    </table>
                </div>

            </div>
        </div>

        <JetModal :show="this.EditUser" :closeable="false">
            <div class="overflow-y-auto max-h-[80vh] pt-3 cursor-default" v-bind:class="{'w-[40rem]' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">

                <p class="font-light text-center text-white-snow text-xl">{{ this.$t("general." + "Edit User") + ' ' + temporal_user_username }}</p>

                <div class="grid grid-cols-10 gap-x-8 px-8 py-4 gap-y-4 font-light text-gray-light text-center">
                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User") }}</p>
                        <DK_Input id="id_user_username" type="text" :placeholder="temporal_user_username" :border="true" width="full"></DK_Input>
                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                        <DK_Input id="id_user_name" type="text" :placeholder="temporal_user_name" :border="true" width="full"></DK_Input>
                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Email") }}</p>
                        <DK_Input id="id_user_email" type="email" :placeholder="temporal_user_email" :border="true" width="full"></DK_Input>
                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                        <DK_Input id="id_user_password" type="password" :border="true" width="full"></DK_Input>
                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                        <DK_Input id="id_user_repeat_password" type="password" :border="true" width="full"></DK_Input>
                    </div>

                    <div class="col-span-5" v-if="this.user.admin == 0">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Group") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_group" name="group"
                            v-model="temporal_user_group">
                            <option v-for="group in groups_names" :key="group" class="bg-darkblue-opa-container"
                                :value="group">{{ group }}</option>
                        </select>
                    </div>

                    <div v-bind:class="{'col-span-10': this.user.admin != 0, 'col-span-5': this.user.admin == 0}">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Timezone") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_timezone" name="timezone"
                            v-model="temporal_user_timezone">
                            <option v-for="timezone in timezones" :key="timezone" class="bg-darkblue-opa-container"
                                :value="timezone">{{ timezone }}</option>
                        </select>
                    </div>

                    <div class="col-span-5">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Language") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_language" name="language"
                            v-model="temporal_user_language">
                            <option v-for="language in languages" :key="language" class="bg-darkblue-opa-container"
                                :value="language">{{ language }}</option>
                        </select>
                    </div>

                    <div class="col-span-5">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User Level") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_user_admin_level"
                            name="user_admin_level" v-model="temporal_user_admin_level">
                            <option v-for="level, index in admin_level" :key="level" class="bg-darkblue-opa-container"
                            v-bind:class="{'hidden': this.user.admin > index}"
                                :value="level">{{ level }}</option>
                        </select>
                    </div>

                    <div class="flex justify-end col-span-10 gap-4 mt-4 pr-0.5">

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditUser()">
                            {{ this.$t("general.Update") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelEditUser()">
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>

                        <DK_Button color="red" :fixedSize="true" v-on:click="this.openDeleteUser(false)">
                            {{ this.$t("general.Delete") }}
                        </DK_Button>

                    </div>
                </div>
            </div>
        </JetModal>

        <JetModal :show="this.DeleteModal" :closeable="false">
            <div class="overflow-y-auto max-h-[80vh] pt-3 cursor-default" v-bind:class="{'w-[28rem]' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">
                <p class="font-light text-center text-white-snow text-xl">{{ this.$t("text." + "Are you sure?") }}</p>

                <p class="mt-3 font-light text-center text-gray-light px-4">{{ this.$t("text." + "Once deleted, there will be no way to retrieve") + ' ' +temporal_user_username}}.</p>

                <div class="grid grid-cols-10 gap-x-8 px-8 py-4 gap-y-4 font-light text-gray-light text-center">

                    <div class="flex justify-center col-span-10 gap-4 mt-4">

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.closeDeleteUser()">
                            {{ this.$t("general.Keep") }}
                        </DK_Button>

                        <DK_Button color="red" :fixedSize="true" v-on:click="this.openDeleteUser(true)">
                            {{ this.$t("general.Delete") }}
                        </DK_Button>

                    </div>
                </div>
            </div>
        </JetModal>

        <JetModal :show="this.CreateUser" :closeable="false">
            <div class="overflow-y-auto max-h-[80vh] pt-3 cursor-default" v-bind:class="{'w-[40rem]' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">

                <p class="font-light text-center text-white-snow text-xl">{{ this.$t("general." + "Create new user") }}</p>

                <div class="grid grid-cols-10 gap-x-8 px-8 py-4 gap-y-4 font-light text-gray-light text-center">

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User") }}</p>
                        <DK_Input id="id_create_user_username" type="text" :placeholder="temporal_user_username" :border="true" width="full"></DK_Input>

                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                        <DK_Input id="id_create_user_name" type="text" :placeholder="temporal_user_name" :border="true" width="full"></DK_Input>

                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Email") }}</p>
                        <DK_Input id="id_create_user_email" type="email" :placeholder="temporal_user_email" :border="true" width="full"></DK_Input>

                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                        <DK_Input id="id_create_user_password" type="password" :border="true" width="full"></DK_Input>

                    </div>

                    <div class="col-span-10">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                        <DK_Input id="id_create_user_repeat_password" type="password" :border="true" width="full"></DK_Input>

                    </div>

                    <div class="col-span-5" v-if="this.user.admin == 0">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Group") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_create_user_group" name="group"
                            v-model="temporal_user_group">
                            <option v-for="group in groups_names" :key="group" class="bg-darkblue-opa-container"
                                :value="group">{{ group }}</option>
                        </select>
                    </div>

                    <div v-bind:class="{'col-span-10': this.user.admin != 0, 'col-span-5': this.user.admin == 0}">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Timezone") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_create_user_timezone"
                            name="timezone" v-model="temporal_user_timezone">
                            <option v-for="timezone in timezones" :key="timezone" class="bg-darkblue-opa-container"
                                :value="timezone">{{ timezone }}</option>
                        </select>
                    </div>

                    <div class="col-span-5">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Language") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_create_user_language"
                            name="language" v-model="temporal_user_language">
                            <option v-for="language in languages" :key="language" class="bg-darkblue-opa-container"
                                :value="language">{{ language }}</option>
                        </select>
                    </div>

                    <div class="col-span-5">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "User Level") }}</p>
                        <select class="modal-input-select" style="width:100%" id="id_create_user_admin_level"
                            name="user_admin_level" v-model="temporal_user_admin_level">
                            <option v-for="level, index in admin_level" :key="level" class="bg-darkblue-opa-container"
                            v-bind:class="{'hidden': this.user.admin > index}"
                                :value="level">{{ level }}</option>
                        </select>
                    </div>

                    <div class="flex justify-end col-span-10 gap-4 mt-4 pr-0.5">

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveCreateUser()">
                            {{ this.$t("general.Create") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelCreateUser()">
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>

                    </div>
                </div>
            </div>
        </JetModal>
    </AppLayout>
</template>

<script>
export default {

    props: ['groups', 'users_list', 'list_timezones', 'user'],

    data() {
        return {
            Back: localStorage.getItem('Back'),
            table: null,
            EditUser: false,
            CreateUser: false,
            DeleteModal: false,
            tempID: null,
            admin_level: ["DK Admin", "Admin", "Analyst", "User"],
            //groups: ["Temporaly disabled"],
            timezones: this.list_timezones,
            languages: ["English", "Spanish", "Chinese"],
            temporal_user_username: null,
            temporal_user_name: null,
            temporal_user_email: null,
            temporal_user_password: null,
            temporal_user_repeat_password: null,
            temporal_user_group: null,
            temporal_user_timezone: null,
            temporal_user_language: null,
            temporal_user_admin_level: null,
            screen_width: 0,
            GW_open: new Array(this.users_list.length).fill(false),
            groups_names: new Array(),
            formatter: (date, user) => {

                date = new Date((new Date(date)).getTime());

                var MM = date.getMonth() + 1;
                var dd = date.getDate();
                var hh = date.getHours();
                var mm = date.getMinutes();
                var ss = date.getSeconds();

                if (MM.toString().length == 1) MM = '0' + MM;
                if (dd.toString().length == 1) dd = '0' + dd;
                if (hh.toString().length == 1) hh = '0' + hh;
                if (mm.toString().length == 1) mm = '0' + mm;
                if (ss.toString().length == 1) ss = '0' + ss;

                return date.getFullYear() + '/' + MM + '/' + dd + ' ' + hh + ':' + mm + ':' + ss;
            }
        }
    },

    beforeCreate: function () {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {
        this.screen_width = window.screen.width;
    },


    mounted() {
        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        this.table = $('#basicTable').DataTable({
            language: {
                url: '/assets/i18n/' + this.user.language + '.json'
            },
            order: (this.screen_width >= 768) ? [[4, "desc"]] : [[1, "asc"]],
            //dom: '<"row"<"col-sm-6"B><"col-sm-6"f>>t<"row"<"col-sm-6"i><"col-sm-6"p>><"clear">',
            searching: true,//(this.screen_width >= 768) ? true : false,
            //paging: true,
            //pageLength: 10,
            info: true,
            ordering: true,
            scrollY: (this.screen_width >= 768) ? 'calc(100vh - 18.5rem)' : 'calc(100vh - 12.5rem)',
            paging: false,
            "columnDefs": [
                { "orderable": false, "targets":  (this.screen_width >= 768) ? [5, 6] : [], }
            ],
        });

    },

    methods: {

        openEditUser(id) {
            let tempID;
            let users_list = this.users_list;

            users_list.forEach(function (user, index) {
                if (user.id == id)
                    tempID = index;
            });

            this.temporal_user_username = users_list[tempID].user;
            this.temporal_user_name = users_list[tempID].name;
            this.temporal_user_email = users_list[tempID].email;
            this.temporal_user_timezone = users_list[tempID].timezone;

            this.groups_names = new Array()

            this.groups.forEach( (group, index) => {
                this.groups_names.push(group.name)
            })

            if(users_list[tempID].idgroup_home != 1){
                this.groups.forEach( (group, index) => {
                    if( users_list[tempID].idgroup_home == group.idgroup){
                        this.temporal_user_group = this.groups[index].name;
                    }
                })
            } else {
                this.temporal_user_group = '';
            }

            switch (users_list[tempID].language) {
                case 'en': this.temporal_user_language = 'English'; break;
                case 'es': this.temporal_user_language = 'Spanish'; break;
                case 'ch': this.temporal_user_language = 'Chinese'; break;
                default: this.temporal_user_language = 'English';

            }

            this.temporal_user_admin_level = this.admin_level[this.users_list[tempID].admin];

            this.tempID = tempID;
            this.EditUser = true;
        },

        CancelEditUser() {
            this.temporal_user_username = this.users_list[this.tempID].user;
            this.temporal_user_name = this.users_list[this.tempID].name;
            this.temporal_user_email = this.users_list[this.tempID].email;
            this.temporal_user_password = null;
            this.temporal_user_repeat_password = null;
            this.temporal_user_group = 'Temporaly disabled'; //this.users_list[this.tempID].group;
            this.temporal_user_timezone = 'UTC'; //this.users_list[this.tempID].timezone;
            this.temporal_user_language = 'English'; //this.users_list[this.tempID].language;
            this.temporal_user_admin_level = this.admin_level[this.users_list[this.tempID].admin];

            this.EditUser = false;
        },

        SaveEditUser() {
            var user_id = this.users_list[this.tempID].id;
            var temporal_user_username = this.users_list[this.tempID].user;
            var temporal_user_name = this.users_list[this.tempID].name;
            var temporal_user_email = this.users_list[this.tempID].email;
            var temporal_user_timezone = this.users_list[this.tempID].timezone;
            var temporal_user_group = this.temporal_user_group;
            var user_username;

            if (document.getElementById('id_user_username').value != '') {
                user_username = document.getElementById('id_user_username').value;
            } else {
                user_username = temporal_user_username;
            }

            var user_name;
            if (document.getElementById('id_user_name').value != '') {
                user_name = document.getElementById('id_user_name').value;
            } else {
                user_name = temporal_user_name;
            }

            var user_email;
            if (document.getElementById('id_user_email').value != '') {
                user_email = document.getElementById('id_user_email').value;
            } else {
                user_email = temporal_user_email;
            }

            var user_password;
            if (document.getElementById('id_user_password').value != '') {
                user_password = document.getElementById('id_user_password').value;
            } else {
                user_password = '';
            }

            var user_repeat_password;
            if (document.getElementById('id_user_repeat_password').value != '') {
                user_repeat_password = document.getElementById('id_user_repeat_password').value;
            } else {
                user_repeat_password = '';
            }

            var user_group;
            if(this.user.admin == 0){
                if (document.getElementById('id_user_group').value != '') {
                    user_group = document.getElementById('id_user_group').value;
                } else {
                    user_group = '';
                }
            }else{
                user_group = temporal_user_group;
            }

            var user_timezone;
            if (document.getElementById('id_user_timezone').value != '') {
                user_timezone = document.getElementById('id_user_timezone').value;
            } else {
                user_timezone = temporal_user_timezone;
            }

            var user_language;
            if (document.getElementById('id_user_language').value != '') {
                user_language = document.getElementById('id_user_language').value;
            } else {
                user_language = '';
            }

            switch (user_language) {
                case 'English': user_language = 'en'; break;
                case 'Spanish': user_language = 'es'; break;
                case 'Chinese': user_language = 'ch'; break;
                default: user_language = '';
            }

            var user_admin_level;
            if (document.getElementById('id_user_admin_level').value != '') {
                user_admin_level = document.getElementById('id_user_admin_level').value;
            } else {
                user_admin_level = '';
            }

            var user_admin_level_num = '';

            switch (user_admin_level) {
                case 'DK Admin': user_admin_level_num = 0; break;
                case 'Admin': user_admin_level_num = 1; break;
                case 'Analyst': user_admin_level_num = 2; break;
                case 'User': user_admin_level_num = 3; break;
            }

            var user_date_update = new Date().toISOString();

            let user_idgroup

            if(user_admin_level_num == 0){
                user_idgroup = 1
            } else {
                this.groups.forEach( (group, index) => {
                    if( user_group == group.name){
                        user_idgroup = group.idgroup;
                    }
                })
            }

            if( user_name != '' &&
                user_username != '' &&
                user_email != '' &&
                user_idgroup != undefined
            ){

                if((user_password == '' && user_repeat_password == '') || this.CheckPasswordPolicies(user_password, user_repeat_password)){

                    const data = {
                        "user": user_username,
                        "name": user_name,
                        "email": user_email,
                        "password": user_password,
                        "confirm_password": user_repeat_password,
                        "idgroup_home": user_idgroup,
                        "timezone": user_timezone,
                        "language": user_language,
                        "admin": user_admin_level_num,
                        "updated_at": user_date_update,
                        // "rol": user_admin_level,
                    };

                    window.emitter.emit('changeLoaderStatus', true, 'orbit')

                    axios({
                        method: 'put',
                        url: window.location.origin + '/api/user/edit/' + this.user.id + '/' + user_id,
                        headers: {
                            'Accept': 'application/json',
                            'Content-Type': 'application/json',
                            'Authorization': 'Bearer ' + this.user.token
                        },
                        data: data
                    })
                        .then((response) => {

                            Object.keys(data).forEach( (key, index) => {
                                if(data[key] != this.users_list[this.tempID][key] && data[key] != '' && data[key] != undefined && data[key] != null){
                                    this.users_list[this.tempID][key] = data[key];
                                }
                            })

                            window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        })
                        .catch((error) => {
                            window.emitter.emit('changeLoaderStatus', false, 'orbit')

                            if(error.response && error.response.status && error.response.status == 429){
                                window.alert( this.$t('text.Api attempts'));
                            }else{
                                return "Failed!", error;
                            }
                        });

                    this.EditUser = false;

                } else if((user_password != '' && user_repeat_password != '') && !(user_password === user_repeat_password)) {

                    window.emitter.emit(
                        'AppLayout_alert',
                        true,
                        this.$t('text.Passwords match'),
                        '',
                        '18rem'
                    )
                } else {

                    window.emitter.emit(
                        'AppLayout_alert',
                        true,
                        this.$t('text.Passwords Policies Title'),
                        this.$t('text.PasswordsPolicies'),
                        '24rem'
                    )
                }
            }else{

                window.emitter.emit(
                    'AppLayout_alert',
                    true,
                    this.$t('text.fill out all the fields - Save'),
                    '',
                    '18rem'
                )
            }
        },

        openDeleteUser(final_delete) {
            if (final_delete) {

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'delete',
                    url: window.location.origin + '/api/user/delete/' + this.user.id + '/' + this.users_list[this.tempID].id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                })
                    .then((response) => {

                        this.users_list.splice(this.tempID, 1);
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                            window.alert( this.$t('text.Api attempts'));
                        }else{
                            return "Failed!", error;
                        }
                    });

                this.EditUser = false;
                this.DeleteModal = false;
            } else {
                this.DeleteModal = true;
            }
        },

        closeDeleteUser() {
            this.DeleteModal = false;
        },

        openCreateUser() {

            this.temporal_user_username = "";
            this.temporal_user_name = "";
            this.temporal_user_email = "";
            this.temporal_user_username = "";
            this.temporal_user_name = "";
            this.temporal_user_email = "";
            this.temporal_user_password = null;
            this.temporal_user_repeat_password = null;

            if(this.user.admin == 0){
                this.temporal_user_group = '';
            } else {
                this.temporal_user_group = {idgroup: this.user.idgroup_selected}
            }

            this.temporal_user_timezone = 'UTC';
            this.temporal_user_language = 'English';
            this.temporal_user_admin_level = 'User';

            this.groups_names = new Array()

            this.groups.forEach( (group, index) => {
                this.groups_names.push(group.name)
            })

            this.CreateUser = true;
        },

        CancelCreateUser() {
            this.temporal_user_username = "";
            this.temporal_user_name = "";
            this.temporal_user_email = "";
            this.temporal_user_password = null;
            this.temporal_user_repeat_password = null;
            this.temporal_user_group = '';
            this.temporal_user_timezone = 'UTC';
            this.temporal_user_language = 'English';
            this.temporal_user_admin_level = 'User';

            this.CreateUser = false;
        },

        SaveCreateUser() {

            var user_username;
            if (document.getElementById('id_create_user_username').value != '') {
                user_username = document.getElementById('id_create_user_username').value;
            } else {
                user_username = this.temporal_user_username;
            }

            var user_name;
            if (document.getElementById('id_create_user_name').value != '') {
                user_name = document.getElementById('id_create_user_name').value;
            } else {
                user_name = this.temporal_user_name;
            }

            var user_email;
            if (document.getElementById('id_create_user_email').value != '') {
                user_email = document.getElementById('id_create_user_email').value;
            } else {
                user_email = this.temporal_user_email;
            }

            var user_password;
            if (document.getElementById('id_create_user_password').value != '') {
                user_password = document.getElementById('id_create_user_password').value;
            } else {
                user_password = this.temporal_user_password;
            }

            var user_repeat_password;
            if (document.getElementById('id_create_user_repeat_password').value != '') {
                user_repeat_password = document.getElementById('id_create_user_repeat_password').value;
            } else {
                user_repeat_password = this.temporal_user_repeat_password;
            }

            var user_group;
            if(document.getElementById('id_create_user_group')){
                if (document.getElementById('id_create_user_group').value != '') {
                    user_group = document.getElementById('id_create_user_group').value;
                } else {
                    user_group = this.temporal_user_group.name;
                }
            }else{
                user_group = this.temporal_user_group.name;
            }

            var user_timezone;
            if (document.getElementById('id_create_user_timezone').value != '') {
                user_timezone = document.getElementById('id_create_user_timezone').value;
            } else {
                user_timezone = this.temporal_user_timezone;
            }

            var user_language;
            if (document.getElementById('id_create_user_language').value != '') {
                user_language = document.getElementById('id_create_user_language').value;
            } else {
                user_language = this.temporal_user_language;
            }

            switch (user_language) {
                case 'English': user_language = 'en'; break;
                case 'Spanish': user_language = 'es'; break;
                case 'Chinese': user_language = 'ch'; break;
                default: user_language = 'en';
            }

            var user_admin_level;
            if (document.getElementById('id_create_user_admin_level').value != '') {
                user_admin_level = document.getElementById('id_create_user_admin_level').value;
            } else {
                user_admin_level = this.temporal_user_admin_level;
            }

            var user_admin_level_num = 3;

            switch (user_admin_level) {
                case 'DK Admin': user_admin_level_num = 0; break;
                case 'Admin': user_admin_level_num = 1; break;
                case 'Analyst': user_admin_level_num = 2; break;
            }

            let temporal_idgroup_home

            if(user_admin_level_num == 0){
                temporal_idgroup_home = 1
            } else {
                if(user_group == undefined) {
                    temporal_idgroup_home = this.user.idgroup_selected
                } else {
                    this.groups.forEach( (group, index) => {
                        if(user_group == group.name){
                            temporal_idgroup_home = group.idgroup;
                        }
                    })
                }
            }

            if( user_name != '' &&
                user_username != '' &&
                user_email != '' &&
                user_password != null &&
                user_repeat_password != null &&
                temporal_idgroup_home != undefined
            ){
                if( this.CheckPasswordPolicies(user_password, user_repeat_password) ){
                    const data = {
                        "name": user_name,
                        "user": user_username,
                        "email": user_email,
                        "password": user_password,
                        "confirm_password": user_repeat_password,
                        "idgroup_home": temporal_idgroup_home,
                        "timezone": user_timezone,
                        "language": user_language,
                        "admin": user_admin_level_num,
                        "updated_at": new Date().toISOString(),
                        "created_at": new Date().toISOString(),
                    };

                    window.emitter.emit('changeLoaderStatus', true, 'orbit')

                    axios({
                        method: 'post',
                        url: window.location.origin + '/api/user/create/' + this.user.id,
                        headers: {
                            'Accept': 'application/json',
                            'Content-Type': 'application/json',
                            'Authorization': 'Bearer ' + this.user.token
                        },
                        data: data
                    })
                        .then((response) => {

                            let obj ={
                                id: response.data.id,
                                ...data
                            };

                            this.users_list.push(obj);

                            window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        })
                        .catch((error) => {
                            window.emitter.emit('changeLoaderStatus', false, 'orbit')

                            if(error.response && error.response.status && error.response.status == 429){
                                window.alert( this.$t('text.Api attempts'));
                            }else{
                                return "Failed!", error;
                            }
                        });

                    this.CreateUser = false;

                } else if( !(user_password === user_repeat_password) ) {

                    window.emitter.emit(
                        'AppLayout_alert',
                        true,
                        this.$t('text.Passwords match'),
                        '',
                        '18rem'
                    )
                } else {

                    window.emitter.emit(
                        'AppLayout_alert',
                        true,
                        this.$t('text.Passwords Policies Title'),
                        this.$t('text.PasswordsPolicies'),
                        '24rem'
                    )
                }


            }else{

                window.emitter.emit(
                    'AppLayout_alert',
                    true,
                    this.$t('text.fill out all the fields'),
                    '',
                    '18rem'
                )
            }


        },

        OpenRow(index){
            this.GW_open[index] = !this.GW_open[index];
        },

        CheckPasswordPolicies(password1, password2) {

            const conditions = [
                /[a-z]/,
                /[A-Z]/,
                /\d/,
                /[!@#$%^&*(),.?":{}|<>-_]/,
                /^.{8,}$/
            ];

            if(password2 && (password1 === password2)){
                return conditions.every(condition => condition.test(password1));
            }else{
                return false;
            }
        }

    },

}
</script>
